@@ -71,12 +71,11 @@ def executer(
         dir.mkdir(parents=True, exist_ok=True)
 
     with basic_pbar() as pbar:
-        pbar.set_description(f"Executing {file.name}")
-        task = pbar.add_task("Waiting ...", total=None)
+        task = pbar.add_task("f"Executing {file.name}", total=None)
         df = isql.run_sql_file(file)
 
-        pbar.update(task, advance=1)
-        pbar.set_description(f"Writing results to {dir}")
+        pbar.update(task, advance=50)
+        pbar.update(task, description=f"Writing results to {dir}")
 
         csv_file = dir / "{file.stem}.csv"
         parquet_file = dir / "{file.stem}.parquet"
@@ -94,6 +93,8 @@ def executer(
                 errors.print(f"[bold red]Output format {out} not supported yet with the base version.[/]", style="bold red")
                 errors.print(f"[dim yellow]Please install `pandas` to get excel support[/]")
                 sys.exit(1)
+        pbar.update(task, advance=50)
+        pbar.update(task, description=f"✅ Donew writing results to {dir}")
         sys.exit(0)
 
 @dev.command(name="test", help="Run tests 🧪")
